@@ -1,8 +1,7 @@
 """Test timezone aware recurrence date times."""
 
 from datetime import datetime
-import pytz
-
+from dateutil import tz
 from django.test import TestCase
 from django.test import override_settings
 
@@ -32,8 +31,8 @@ class FieldTest(TestCase):
         field = RecurrenceField()
         cleaned_value = field.clean(value)
         assert cleaned_value.rrules == [rule]
-        assert cleaned_value.dtstart == datetime(2014, 1, 1, 0, 0, 0, tzinfo=pytz.utc)
-        assert cleaned_value.dtend == datetime(2014, 2, 3, 0, 0, 0, tzinfo=pytz.utc)
+        assert cleaned_value.dtstart == datetime(2014, 1, 1, 0, 0, 0, tzinfo=tz.UTC)
+        assert cleaned_value.dtend == datetime(2014, 2, 3, 0, 0, 0, tzinfo=tz.UTC)
 
         field = RecurrenceField(accept_dtstart=False, accept_dtend=False)
         cleaned_value = field.clean(value)
@@ -43,19 +42,19 @@ class FieldTest(TestCase):
 
     def test_dt_start_and_dtend_converts_to_utc(self):
         """Convert the values for dtstart and dtend to UTC."""
-        tz = pytz.timezone('America/Adak')
+        tz_adak = tz.gettz('America/Adak')
 
         limits = Recurrence(
-            dtstart=datetime(2014, 1, 1, 0, 0, 0, tzinfo=tz),
-            dtend=datetime(2014, 2, 3, 0, 0, 0, tzinfo=tz),
+            dtstart=datetime(2014, 1, 1, 0, 0, 0, tzinfo=tz_adak),
+            dtend=datetime(2014, 2, 3, 0, 0, 0, tzinfo=tz_adak),
         )
 
         value = recurrence.serialize(limits)
 
         field = RecurrenceField(required=False)
         cleaned_value = field.clean(value)
-        assert cleaned_value.dtstart == datetime(2014, 1, 1, 0, 0, 0, tzinfo=tz).astimezone(pytz.utc)
-        assert cleaned_value.dtend == datetime(2014, 2, 3, 0, 0, 0, tzinfo=tz).astimezone(pytz.utc)
+        assert cleaned_value.dtstart == datetime(2014, 1, 1, 0, 0, 0, tzinfo=tz_adak).astimezone(tz.UTC)
+        assert cleaned_value.dtend == datetime(2014, 2, 3, 0, 0, 0, tzinfo=tz_adak).astimezone(tz.UTC)
         assert cleaned_value.dtstart.tzname() == 'UTC'
         assert cleaned_value.dtend.tzname() == 'UTC'
 
@@ -72,18 +71,18 @@ class FieldTest(TestCase):
         field = RecurrenceField()
         cleaned_value = field.clean(value)
         assert cleaned_value.rdates == [
-            datetime(2014, 1, 1, 0, 0, 0, tzinfo=pytz.utc),
-            datetime(2014, 1, 2, 0, 0, 0, tzinfo=pytz.utc),
+            datetime(2014, 1, 1, 0, 0, 0, tzinfo=tz.UTC),
+            datetime(2014, 1, 2, 0, 0, 0, tzinfo=tz.UTC),
         ]
         for rdate in cleaned_value.rdates:
             assert rdate.tzname() == 'UTC'
 
     def test_aware_rdates_converted_to_utc(self):
-        tz = pytz.timezone('America/Adak')
+        tz_adak = tz.gettz('America/Adak')
         limits = Recurrence(
             rdates=[
-                datetime(2014, 1, 1, 0, 0, 0, tzinfo=tz),
-                datetime(2014, 1, 2, 0, 0, 0, tzinfo=tz),
+                datetime(2014, 1, 1, 0, 0, 0, tzinfo=tz_adak),
+                datetime(2014, 1, 2, 0, 0, 0, tzinfo=tz_adak),
             ],
         )
 
@@ -92,8 +91,8 @@ class FieldTest(TestCase):
         field = RecurrenceField()
         cleaned_value = field.clean(value)
         assert cleaned_value.rdates == [
-            datetime(2014, 1, 1, 0, 0, 0, tzinfo=tz).astimezone(pytz.utc),
-            datetime(2014, 1, 2, 0, 0, 0, tzinfo=tz).astimezone(pytz.utc),
+            datetime(2014, 1, 1, 0, 0, 0, tzinfo=tz_adak).astimezone(tz.UTC),
+            datetime(2014, 1, 2, 0, 0, 0, tzinfo=tz_adak).astimezone(tz.UTC),
         ]
         for rdate in cleaned_value.rdates:
             assert rdate.tzname() == 'UTC'
@@ -111,18 +110,18 @@ class FieldTest(TestCase):
         field = RecurrenceField()
         cleaned_value = field.clean(value)
         assert cleaned_value.exdates == [
-            datetime(2014, 1, 1, 0, 0, 0, tzinfo=pytz.utc),
-            datetime(2014, 1, 2, 0, 0, 0, tzinfo=pytz.utc),
+            datetime(2014, 1, 1, 0, 0, 0, tzinfo=tz.UTC),
+            datetime(2014, 1, 2, 0, 0, 0, tzinfo=tz.UTC),
         ]
         for rdate in cleaned_value.exdates:
             assert rdate.tzname() == 'UTC'
 
     def test_aware_exdates_converted_to_utc(self):
-        tz = pytz.timezone('America/Adak')
+        tz_adak = tz.gettz('America/Adak')
         limits = Recurrence(
             exdates=[
-                datetime(2014, 1, 1, 0, 0, 0, tzinfo=tz),
-                datetime(2014, 1, 2, 0, 0, 0, tzinfo=tz),
+                datetime(2014, 1, 1, 0, 0, 0, tzinfo=tz_adak),
+                datetime(2014, 1, 2, 0, 0, 0, tzinfo=tz_adak),
             ],
         )
 
@@ -131,8 +130,8 @@ class FieldTest(TestCase):
         field = RecurrenceField()
         cleaned_value = field.clean(value)
         assert cleaned_value.exdates == [
-            datetime(2014, 1, 1, 0, 0, 0, tzinfo=tz).astimezone(pytz.utc),
-            datetime(2014, 1, 2, 0, 0, 0, tzinfo=tz).astimezone(pytz.utc),
+            datetime(2014, 1, 1, 0, 0, 0, tzinfo=tz_adak).astimezone(tz.UTC),
+            datetime(2014, 1, 2, 0, 0, 0, tzinfo=tz_adak).astimezone(tz.UTC),
         ]
         for rdate in cleaned_value.exdates:
             assert rdate.tzname() == 'UTC'
@@ -147,11 +146,11 @@ class FieldTest(TestCase):
         value = recurrence.serialize(recurs)
         field = RecurrenceField()
         cleaned_value = field.clean(value)
-        assert cleaned_value.rrules[0].until == datetime(2014, 1, 1, 0, 0, 0, tzinfo=pytz.utc)
+        assert cleaned_value.rrules[0].until == datetime(2014, 1, 1, 0, 0, 0, tzinfo=tz.UTC)
 
     def test_aware_until_gets_converted_to_utc(self):
-        tz = pytz.timezone('America/Adak')
-        until = datetime(2014, 1, 1, 0, 0, 0, tzinfo=tz)
+        tz_adak = tz.gettz('America/Adak')
+        until = datetime(2014, 1, 1, 0, 0, 0, tzinfo=tz_adak)
         recurs = Recurrence(
             rrules=[Rule(
                 recurrence.DAILY,
@@ -161,7 +160,7 @@ class FieldTest(TestCase):
         value = recurrence.serialize(recurs)
         field = RecurrenceField()
         cleaned_value = field.clean(value)
-        assert cleaned_value.rrules[0].until == until.astimezone(pytz.utc)
+        assert cleaned_value.rrules[0].until == until.astimezone(tz.UTC)
 
 
 @override_settings(RECURRENCE_USE_TZ=True, USE_TZ=True)
@@ -186,30 +185,30 @@ class SaveTest(TestCase):
         event.refresh_from_db()
 
         instances = event.recurs.between(
-            datetime(2010, 1, 1, 0, 0, 0, tzinfo=pytz.utc),
-            datetime(2020, 12, 31, 0, 0, 0, tzinfo=pytz.utc)
+            datetime(2010, 1, 1, 0, 0, 0, tzinfo=tz.UTC),
+            datetime(2020, 12, 31, 0, 0, 0, tzinfo=tz.UTC)
         )
 
         assert instances == [
-            datetime(2014, 1, 1, 0, 0, tzinfo=pytz.utc),
-            datetime(2014, 1, 8, 0, 0, tzinfo=pytz.utc),
-            datetime(2014, 1, 15, 0, 0, tzinfo=pytz.utc),
-            datetime(2014, 1, 22, 0, 0, tzinfo=pytz.utc),
-            datetime(2014, 1, 29, 0, 0, tzinfo=pytz.utc),
-            datetime(2014, 2, 3, 0, 0, tzinfo=pytz.utc)  # We always get dtend
+            datetime(2014, 1, 1, 0, 0, tzinfo=tz.UTC),
+            datetime(2014, 1, 8, 0, 0, tzinfo=tz.UTC),
+            datetime(2014, 1, 15, 0, 0, tzinfo=tz.UTC),
+            datetime(2014, 1, 22, 0, 0, tzinfo=tz.UTC),
+            datetime(2014, 1, 29, 0, 0, tzinfo=tz.UTC),
+            datetime(2014, 2, 3, 0, 0, tzinfo=tz.UTC)  # We always get dtend
         ]
 
         event = EventWithNoNulls.objects.get(pk=event.pk)
 
         expected_limits = Recurrence(
-            dtstart=datetime(2014, 1, 1, 0, 0, 0, tzinfo=pytz.utc),
-            dtend=datetime(2014, 2, 3, 0, 0, 0, tzinfo=pytz.utc),
+            dtstart=datetime(2014, 1, 1, 0, 0, 0, tzinfo=tz.UTC),
+            dtend=datetime(2014, 2, 3, 0, 0, 0, tzinfo=tz.UTC),
             rrules=[rule]
         )
 
         assert event.recurs == expected_limits
 
         assert event.recurs.between(
-            datetime(2010, 1, 1, 0, 0, 0, tzinfo=pytz.utc),
-            datetime(2020, 12, 31, 0, 0, 0, tzinfo=pytz.utc)
+            datetime(2010, 1, 1, 0, 0, 0, tzinfo=tz.UTC),
+            datetime(2020, 12, 31, 0, 0, 0, tzinfo=tz.UTC)
         ) == instances
